cordova.define("pt.xarevision.location.NativeLocation", function(require, exports, module) {

var exec = require('cordova/exec'),
	PositionError = require('./PositionError'),
	Position = require('./Position');


var NativeLocation = function()
{
    this.onpermissions = null;
};

/**
 * Get current position
 */
NativeLocation.prototype.getCurrentPosition =  function(options) {
    return new Promise(function(resolve, reject){
        var success = function (p) {
            var pos = new Position({
                latitude: p.latitude,
                longitude: p.longitude,
                altitude: p.altitude,
                accuracy: p.accuracy,
                heading: p.heading,
                velocity: p.velocity,
                altitudeAccuracy: p.altitudeAccuracy
            }, (p.timestamp === undefined ? new Date() : ((p.timestamp instanceof Date) ? p.timestamp : new Date(p.timestamp))));

            resolve(pos);
        };

        var error = function (e) {
            var err = new PositionError(e.code, e.message);
            reject(err);
        };
        exec(success, error, "NativeLocation", "getLocation", [options.maximumAge, options.timeout, options.type]);
    }, options);
};

/**
 * Get last known position
 */
NativeLocation.prototype.getLastKnownPosition = function (options) {
    return new Promise(function(resolve, reject){
        var success = function (p) {
            var pos = new Position({
                latitude: p.latitude,
                longitude: p.longitude,
                altitude: p.altitude,
                accuracy: p.accuracy,
                heading: p.heading,
                velocity: p.velocity,
                altitudeAccuracy: p.altitudeAccuracy
            }, (p.timestamp === undefined ? new Date() : ((p.timestamp instanceof Date) ? p.timestamp : new Date(p.timestamp))));

            resolve(pos);
        };
        var error = function (e) {
            var err = new PositionError(e.code, e.message);
            reject(err);
        };
        exec(success, error, "NativeLocation", "getLastKnownLocation", [options.maximumAge, options.type]);
    }, options)
};

/**
 * Request Permissions
 */
NativeLocation.prototype.requestPermissions = function (forcePermissions) {
    var that = this;
    return new Promise(function(resolve, reject){
        var success = function (requesting) {
            if(requesting == true)
            {
                if(typeof  that.onpermissions === "function")
                {
                    that.onpermissions();
                }
            }
            else
            {
                resolve();
            }
        };
        var error = function (err) {
            reject(err);
        };
        exec(success, error, "NativeLocation", "requestPermissions", [forcePermissions]);
    }, forcePermissions)
};

module.exports = NativeLocation;

});
